Check that grouping specified to PKNCA is likely to be correct If the grouping results in most groups having too few datapoints to perform NCA and calculate half-life, then the grouping is likely wrong.
check_nca_grouping.RdCheck that grouping specified to PKNCA is likely to be correct
If the grouping results in most groups having too few datapoints to
perform NCA and calculate half-life, then the grouping is likely wrong.
Usage
check_nca_grouping(
data,
groups,
dictionary,
settings = list(),
threshold = 0.7,
verbose = TRUE
)Arguments
- data
dataset in pre-parse format, preferrably created using
create_nca_data(). Can also be a NONMEM-style dataset with EVID=0|1 column indicating PK an dosing data.- groups
optional grouping variable, e.g.
ACTARM.- dictionary
abridged data dictionary for the input dataset, specified as list object. Requires at least entries for
subject_id,time,conc,dose. Optional entries are:visit. If required entries are specified only partially, then default values (i.e. CDISC) nomenclature will be imputed for missing identifiers.- settings
list of settings for NCA. Provided setting names can either be settings recognized directly by
pknca, or settings that are included in the map provided bynca_settings_map()(which are then mapped topkncasetting names). In addition to standard PKNCA settings, the following settings are handled internally and not passed to PKNCA:min.hl.time(orminHalfLifeTime): minimum time required for a data point to be eligible for the lambda-z (terminal slope) calculation. Any data points with time < this value are excluded from the lambda-z fit (but remain in the analysis for other parameters such as Cmax and AUClast). This is implemented by settingexclude_lambda_zflags internally.
- threshold
the fraction of data to be allowed to have too few data points for NCA.
- verbose
verbose output?