get_nca_units.Rd
Get a table of units from a raw PKNCA object
get_nca_units(data, units_col = "PPSTRESU")
PKNCA output object
the name of the column holding the units, default is PPSTRESU
PPSTRESU
data.frame with name and unit columns
name
unit